==> haskell-src-exts-1.20.2-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts
version: 1.20.2
id: haskell-src-exts-1.20.2-udiE50EOtSJb0KMyu3jrK
key: haskell-src-exts-1.20.2-udiE50EOtSJb0KMyu3jrK
license: BSD-3-Clause
maintainer: Matthew Pickering <matthewtpickering@gmail.com>
author: Niklas Broberg
stability: Stable
homepage: https://github.com/haskell-suite/haskell-src-exts
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description:
    Haskell-Source with Extensions (HSE, haskell-src-exts)
    is a standalone parser for Haskell. In addition to
    standard Haskell, all extensions implemented in GHC are supported.
    .
    Apart from these standard extensions,
    it also handles regular patterns as per the HaRP extension
    as well as HSX-style embedded XML syntax.
category: Language
abi: 7ee77880d5f860d88355ec2bf205631b
exposed: True
exposed-modules:
    Language.Haskell.Exts Language.Haskell.Exts.Build
    Language.Haskell.Exts.Comments Language.Haskell.Exts.ExactPrint
    Language.Haskell.Exts.Extension Language.Haskell.Exts.Fixity
    Language.Haskell.Exts.Lexer Language.Haskell.Exts.Parser
    Language.Haskell.Exts.Pretty Language.Haskell.Exts.SrcLoc
    Language.Haskell.Exts.Syntax
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser
import-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-1.20.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-1.20.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haskell-src-exts-1.20.2
hs-libraries: HShaskell-src-exts-1.20.2-udiE50EOtSJb0KMyu3jrK
depends:
    array-0.5.2.0 pretty-1.1.3.6 cpphs-1.20.8-EnghLHV7NxH7UxslX9e8Ie
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             cpphs-1.20.8-EnghLHV7NxH7UxslX9e8Ie=09fd11a80f9f502a940ff803c360d0c4
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
haddock-html: /usr/share/doc/haskell-src-exts/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-1.20.2-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts
version: 1.20.2
id: haskell-src-exts-1.20.2-87EuqNobubL7zDhw6Vv3Ck
key: haskell-src-exts-1.20.2-87EuqNobubL7zDhw6Vv3Ck
license: BSD-3-Clause
maintainer: Matthew Pickering <matthewtpickering@gmail.com>
author: Niklas Broberg
stability: Stable
homepage: https://github.com/haskell-suite/haskell-src-exts
synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
description:
    Haskell-Source with Extensions (HSE, haskell-src-exts)
    is a standalone parser for Haskell. In addition to
    standard Haskell, all extensions implemented in GHC are supported.
    .
    Apart from these standard extensions,
    it also handles regular patterns as per the HaRP extension
    as well as HSX-style embedded XML syntax.
category: Language
abi: ed433356a56b0b76eb10c0e9673c3a9d
exposed: True
exposed-modules:
    Language.Haskell.Exts Language.Haskell.Exts.Build
    Language.Haskell.Exts.Comments Language.Haskell.Exts.ExactPrint
    Language.Haskell.Exts.Extension Language.Haskell.Exts.Fixity
    Language.Haskell.Exts.Lexer Language.Haskell.Exts.Parser
    Language.Haskell.Exts.Pretty Language.Haskell.Exts.SrcLoc
    Language.Haskell.Exts.Syntax
hidden-modules: Language.Haskell.Exts.ExtScheme
                Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                Language.Haskell.Exts.InternalLexer
                Language.Haskell.Exts.ParseUtils
                Language.Haskell.Exts.InternalParser
import-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-1.20.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-1.20.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/haskell-src-exts-1.20.2
hs-libraries: HShaskell-src-exts-1.20.2-87EuqNobubL7zDhw6Vv3Ck
depends:
    array-0.5.2.0 pretty-1.1.3.6 cpphs-1.20.8-EnghLHV7NxH7UxslX9e8Ie
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             cpphs-1.20.8-EnghLHV7NxH7UxslX9e8Ie=09fd11a80f9f502a940ff803c360d0c4
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
haddock-html: /usr/share/doc/haskell-src-exts/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
